# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


Buffer = object
DISPLAY_TEXT = ''
HELP_TEXT = ''
NAVKEYS = tuple()
PRINT_UPDATE_MAX_TIME = 0
PseudoFileErr = object
PseudoFileIn = object
PseudoFileOut = object
Shell = object
ShellFacade = object
ShellFrame = object
VERSION = ''
cd = dummy_function
cmp_to_key = dummy_function
ls = dummy_function
magic = dummy_function
pwd = dummy_function
sx = dummy_function
