# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EditStartupScriptDialog = object
Frame = object
ID_ABOUT = object
ID_AUTOCOMP_DOUBLE = object
ID_AUTOCOMP_MAGIC = object
ID_AUTOCOMP_SHOW = object
ID_AUTOCOMP_SINGLE = object
ID_AUTO_SAVESETTINGS = object
ID_CALLTIPS_INSERT = object
ID_CALLTIPS_SHOW = object
ID_CLEAR = object
ID_CLEARHISTORY = object
ID_CLOSE = object
ID_COPY = object
ID_COPY_PLUS = object
ID_CUT = object
ID_DELSETTINGSFILE = object
ID_EDITSTARTUPSCRIPT = object
ID_EMPTYBUFFER = object
ID_ENABLEAUTOSYMPY = object
ID_ENABLESHELLMODE = object
ID_EXECSTARTUPSCRIPT = object
ID_EXIT = object
ID_FIND = object
ID_FINDNEXT = object
ID_FINDPREVIOUS = object
ID_HELP = object
ID_HIDEFOLDINGMARGIN = object
ID_NAMESPACE = object
ID_NEW = object
ID_OPEN = object
ID_PASTE = object
ID_PASTE_PLUS = object
ID_PRINT = object
ID_REDO = object
ID_REVERT = object
ID_SAVE = object
ID_SAVEACOPY = object
ID_SAVEAS = object
ID_SAVEHISTORY = object
ID_SAVEHISTORYNOW = object
ID_SAVESETTINGS = object
ID_SELECTALL = object
ID_SHOWPYSLICESTUTORIAL = object
ID_SHOWTOOLS = object
ID_SHOW_LINENUMBERS = object
ID_TOGGLE_MAXIMIZE = object
ID_UNDO = object
ID_WRAP = object
ShellFrameMixin = object
VERSION = ''
