# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


PseudoFile = object
PseudoFileErr = object
PseudoFileIn = object
PseudoFileOut = object
PseudoKeyword = object
