# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


BytesIO = object
getAllAttributeNames = dummy_function
getAttributeNames = dummy_function
getAutoCompleteList = dummy_function
getBaseObject = dummy_function
getCallTip = dummy_function
getConstructor = dummy_function
getRoot = dummy_function
getTokens = dummy_function
hasattrAlwaysReturnsTrue = dummy_function
rtrimTerminus = dummy_function
string_types = tuple()
